<?php

require __DIR__ . "/autoloader.php";
require __DIR__ . "/vendor/autoload.php";
require __DIR__ . "/vendor/zeedhi/framework/bootstrap.php";
require __DIR__ . "/vendor/teknisa/libraries/scripts/bootstrap.php";

$instanceManager = \Zeedhi\Framework\DependencyInjection\InstanceManager::getInstance();

$environment = __DIR__.'/../../../backend/config/environment.xml';
$db          = __DIR__.'/../../../backend/config/db.xml';
$report      = __DIR__.'/../../../backend/config/report.xml';
$parameters  = __DIR__.'/../../../backend/config/parameters.xml';
$general     = __DIR__.'/../../../backend/config/general.xml';

if (realpath($parameters)) $instanceManager->loadFromFile($parameters);

$container = $instanceManager->getContainer();

$routes = array();
$routes[] = __DIR__ . '/vendor/teknisa/libraries/libRoutes.json';
$routes[] = __DIR__ . "/vendor/zeedhi/preferences/routes.json";

if ($container->hasParameter('use_zhu_acl') && $container->getParameter('use_zhu_acl')){
    $acl = __DIR__.'/config/acl.xml';
    if(realpath($acl)){
        $instanceManager->loadFromFile($acl);
    }
    require __DIR__ . "/vendor/zeedhi/zhuaclbackend/service/bootstrap.php";
    $routes[] = __DIR__."/vendor/zeedhi/zhuaclbackend/config/routes.json";
}

if ($container->hasParameter('use_zhu_update') && $container->getParameter('use_zhu_update') == 'true'){
    $zhu = __DIR__ . '/config/zhuUpdate.xml';

    if(realpath($zhu)){
        $instanceManager->loadFromFile($zhu);
    }
}

if ($container->hasParameter('use_zhu_log') && $container->getParameter('use_zhu_log')) {
    $zhuDateFormat = $container->getParameter('zhuLogDateFormat');
    $ignoredRoutes = $container->hasParameter('logIgnoredRoutes') ? $container->getParameter('logIgnoredRoutes') : [];

    require __DIR__ . "/vendor/zeedhi/zhulog/config/bootstrap.php";
    $routes[] = __DIR__."/vendor/zeedhi/zhulog/config/routes.json";

    $libLog = __DIR__.'/vendor/teknisa/libraries/zhuLog.xml';
    if(realpath($libLog)){
        $instanceManager->loadFromFile($libLog);
    }

    $container->setParameter('logIgnoredRoutes', $ignoredRoutes);
    $container->setParameter('zhuLogDateFormat', $zhuDateFormat);
}

if (!realpath($db))      $db     = __DIR__ . "/config/db.xml";
if (!realpath($report))  $report = __DIR__ . "/config/report.xml";
if (realpath($general))  $instanceManager->loadFromFile($general);

$mapping = file_get_contents(__DIR__.'/config/servicesMapping.json');
$mapping = json_decode($mapping, true);

foreach ($mapping as $path) {
    $ext = substr(strrchr($path,'.'),1);
    if($ext === 'xml')
        $instanceManager->loadFromFile(__DIR__.$path);
    if($ext === 'json')
        $routes[] = __DIR__.$path;
}

$instanceManager->loadFromFile($db);
$instanceManager->loadFromFile(__DIR__ . '/config/environment.xml');
$instanceManager->loadFromFile(__DIR__ . '/vendor/zeedhi/preferences/services.xml');
if (realpath($report)) $instanceManager->loadFromFile($report);

if ($container->hasParameter('use_zhu_log') && $container->getParameter('use_zhu_log')) {
    $log = __DIR__.'/config/log.xml';
    $logListener = __DIR__.'/config/logListener.xml';
    $instanceManager->loadFromFile($log);
    $instanceManager->loadFromFile($logListener);
}

/** @var \Doctrine\ORM\EntityManager $entity_manager */
$entity_manager = $instanceManager->getService('entityManager');
\Setforms2\Shared\Registry::store("EntityManager", $entity_manager);
\Setforms2\Shared\Registry::store("EntityManagerConnection", $entity_manager->getConnection());

$instanceManager->registerService('routeParser', new \Zeedhi\Framework\Routing\Parsers\JSONFormat($routes));
$instanceManager->compile();